mod add_hosted_service_strategy;
pub use add_hosted_service_strategy::*;

mod add_background_service_strategy;
pub use add_background_service_strategy::*;

mod add_configuration_strategy;
pub use add_configuration_strategy::*;